@@ -65,7 +65,7 @@ class KongAuth(BaseAuth):
             session.seend_cookie = False
             mysession = current_app.session_interface.get_session(g.jwt)
             # 如果只通过了Kong 认证，且没有在redis中存该session key ，如：key auth，则写入kong 认证的信息给session
-            if request.headers.get('X-Consumer-Username') and request.headers.get('X-Consumer-Custom-Id') and not session.get('uid'):
+            if request.headers.get('X-Consumer-Username') and request.headers.get('X-Consumer-Custom-Id') and not mysession:
                 session.update(dict({'uid':g.user_id ,'uname':g.user_name,
                             'systemuser':False,
                             'manageuser':False,
